==> haskell-microlens-platform-0.4.4.1-62-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-platform
version:              0.4.4.1
visibility:           public
id:                   microlens-platform-0.4.4.1-35Befm5lYDmDhJtZuqOjlw
key:                  microlens-platform-0.4.4.1-35Befm5lYDmDhJtZuqOjlw
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  dd32cb29f0f38fd9ee29aeb3151d9f81
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microlens-platform-0.4.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microlens-platform-0.4.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microlens-platform-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-platform
hs-libraries:         HSmicrolens-platform-0.4.4.1-35Befm5lYDmDhJtZuqOjlw
depends:
    base-4.17.2.1 hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.1-CjElCeEmbPg9RMtJsMDsV0
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.4.1-67-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-platform
version:              0.4.4.1
visibility:           public
id:                   microlens-platform-0.4.4.1-7nb4BVSMqSUKsh2FI0sG1h
key:                  microlens-platform-0.4.4.1-7nb4BVSMqSUKsh2FI0sG1h
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  b9ce40f35c39b9414d5d60fb322a6d11
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/microlens-platform-0.4.4.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/microlens-platform-0.4.4.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/microlens-platform-0.4.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-platform
hs-libraries:         HSmicrolens-platform-0.4.4.1-7nb4BVSMqSUKsh2FI0sG1h
depends:
    base-4.18.3.0 hashable-1.4.7.0-17jkMnZLQLs4o2IKp4JpPo
    microlens-0.4.14.0-4ENPj0tHNR0GzcdT8Xo5Q8
    microlens-ghc-0.4.15.1-M8xMlpmFXNKiiBkrwmsv7
    microlens-mtl-0.2.1.0-BPqflcywilRLKDKsRXDgDa
    microlens-th-0.4.3.17-F1IcXkuPeIB4kMaxwhk9vS text-2.0.2
    unordered-containers-0.2.20.1-Kme465eYitW9JyEVR89fCg
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
